==> cmsmadesimple-1.5.3.tgz: cms/modules/ModuleManager/lang/ext/fr_FR.php <==
<?php
$lang['use_at_your_own_risk'] = 'Utilisation &agrave; vos risques et p&eacute;rils';
$lang['compatibility_disclaimer'] = 'Les modules affich&eacute;s ici sont fournis par les d&eacute;veloppeurs de CMS, et des tiers ind&eacute;pendants. Nous ne pouvons garantir que les modules offerts ici soit fonctionnels, test&eacute;s, ou compatibles avec votre syst&egrave;me. Vous &ecirc;tes encourag&eacute;s &agrave; lire les informations qui se trouvent dans l&#039;aide et sur les liens pour chaque module avant l&#039;installation.';
$lang['notice'] = 'Avertissement';
$lang['general_notice'] = 'Les version affich&eacute;es ici repr&eacute;sentent les derniers fichiers au format XML de votre d&eacute;pot s&eacute;lectionn&eacute; (lCMSMS %s). Ils peuvent &ecirc;tre ou non la derniere version disponible. Vous pouvez afficher les d&eacute;tails sur le module vous avez s&eacute;lectionn&eacute;. Si vous utilisez la valeur par d&eacute;faut, vous pouvez le faire en tapant le nom du module dans le champ de recherche sur la %s et en cliquant sur le bouton &quot;Rechercher&quot;.';
$lang['incompatible'] = 'Incompatible ';
$lang['prompt_settings'] = 'Configuration';
$lang['prompt_otheroptions'] = 'Autres options';
$lang['reset'] = 'R&eacute;initialisation';
$lang['error_permissions'] = '<strong><em>ATTENTION :</em></strong>Vous n&#039;avez pas les permissions suffisantes pour installer les modules. Vous pouvez avoir des prob&egrave;mes avec PHP Safe mode. Merci de v&eacute;rifier que le safe mode est OFF, et que les permissions des fichiers sont suffisantes.';
$lang['error_minimumrepository'] = 'La version du d&eacute;pot de modules n&#039;est pas compatible avec ce &quot;module manager&quot;';
$lang['prompt_reseturl'] = 'Remettre l&#039;URL par d&eacute;faut&nbsp;';
$lang['prompt_resetcache'] = 'Effacer les donn&eacute;es du cache local&nbsp;';
$lang['prompt_dl_chunksize'] = 'Taille de t&eacute;l&eacute;chargement (Kb)&nbsp;';
$lang['text_dl_chunksize'] = 'La taille maximale des donn&eacute;es &agrave; t&eacute;l&eacute;charger du serveur en une fois (lors de l&#039;installation d&#039;un module)';
$lang['error_nofilesize'] = 'Aucun param&egrave;tre de taill&eacute; sp&eacute;cifi&eacute;';
$lang['error_nofilename'] = 'Aucun param&egrave;tre de nom de fichier sp&eacute;cifi&eacute;';
$lang['error_checksum'] = 'Erreur Checksum. Ceci indique probablement qu&#039;il y a un fichier corrompu, soit lorsqu&#039;il a &eacute;t&eacute; t&eacute;l&eacute;charg&eacute; sur le d&eacute;p&ocirc;t (repository), soit lorsqu&#039;il a &eacute;t&eacute; transmis &agrave; votre machine.';
$lang['cantdownload'] = 'Impossible de t&eacute;l&eacute;charger';
$lang['download'] = 'T&eacute;l&eacute;charger et installer';
$lang['error_moduleinstallfailed'] = 'L&#039;installation du module n&#039;a pas r&eacute;ussi';
$lang['error_connectnomodules'] = 'Bien qu&#039;une connection au d&eacute;p&ocirc;t de module aie &eacute;t&eacute; &eacute;tablie avec succ&egrave;s, il appara&icirc;t que ce d&eacute;p&ocirc;t ne partage aucun module pour l&#039;instant.';
$lang['submit'] = 'Soumettre';
$lang['text_repository_url'] = 'L&#039;URL doit &ecirc;tre dans un format tel que http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'URL du d&eacute;p&ocirc;t de modules&nbsp;';
$lang['availmodules'] = 'Modules disponibles';
$lang['preferences'] = 'Pr&eacute;f&eacute;rences';
$lang['preferencessaved'] = 'Les pr&eacute;f&eacute;rences ont &eacute;t&eacute; mises &agrave; jour';
$lang['repositorycount'] = 'Modules trouv&eacute;s dans le d&eacute;p&ocirc;t';
$lang['instcount'] = 'Modules install&eacute;s';
$lang['availablemodules'] = 'Statut des modules disponibles dans le d&eacute;p&ocirc;t actuel';
$lang['helptxt'] = 'Aide';
$lang['abouttxt'] = '&Agrave; propos';
$lang['xmltext'] = 'Fichier XML';
$lang['nametext'] = 'Nom du module';
$lang['vertext'] = 'Version ';
$lang['sizetext'] = 'Taille (octets)';
$lang['statustext'] = 'Statut/Action';
$lang['uptodate'] = 'Install&eacute;';
$lang['install'] = 'installer';
$lang['newerversion'] = 'Nouvelle version install&eacute;e';
$lang['onlynewesttext'] = 'Afficher uniquement les nouvelles versions&nbsp;';
$lang['upgrade'] = 'Mise &agrave; jour';
$lang['error_nosoapconnect'] = 'Impossible de se connecter au serveur SOAP';
$lang['error_soaperror'] = 'Probl&egrave;me SOAP';
$lang['error_norepositoryurl'] = 'L&#039;URL du d&eacute;p&ocirc;t de module n&#039;a pas &eacute;t&eacute; sp&eacute;cifi&eacute;';
$lang['friendlyname'] = 'Gestionnaire de Modules';
$lang['postinstall'] = 'Message apr&egrave;s l&#039;installation';
$lang['postuninstall'] = 'Le module Gestionnaire de modules (Module Manager) a &eacute;t&eacute; d&eacute;sinstall&eacute;. Les utilisateurs n&#039;auront plus la possibilit&eacute; d&#039;installer des modules depuis des d&eacute;p&ocirc;ts distants. Cependant, l&#039;installation locale est toujours possible.';
$lang['really_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir d&eacute;sinstaller ce module&nbsp;? Vous allez perdre toutes ses fonctionalit&eacute;s.';
$lang['uninstalled'] = 'Module d&eacute;sinstall&eacute;.';
$lang['installed'] = 'La version %s du module est install&eacute;e.';
$lang['upgraded'] = 'Module mis &agrave; jour &agrave; la version %s.';
$lang['moddescription'] = 'Un client pour le d&eacute;pot de modules (ModuleRepository), ce module permet la pr&eacute;visualisation, et l&#039;installation de modules depuis des sites distants sans avoir besoin d&#039;utiliser le ftp, ou de d&eacute;zipper des archives. Les fichier XML de modules sont t&eacute;l&eacute;charg&eacute;s en utilisant SOAP, l&#039;int&eacute;grit&eacute; est v&eacute;rifi&eacute;e et automatiquement ajust&eacute;e.';
$lang['error'] = 'Erreur&nbsp;!';
$lang['admindescription'] = 'Un outils pour trouver et installer des modules depuis des sites distants.';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;, veuillez v&eacute;rifier les permissions.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 janvier 2006. Version initiale.</li>
<li>Version 1.1. juillet 2006. Distribu&eacute; avec 1.0- beta</li>
<li>Version 1.1.1 Ao&ucirc;t 2006.  Requiert la version 1.0.1 de nuSOAP</li>
<li>Version 1.1.2 septembre 2006.  Correction d&#039;une erreur qui emp&ecirc;chait les mises &agrave; jour</li>
<li>Version 1.1.3 Septembre, 2006.
  <ul>
  <li>Requiert au minimum CMS Version 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
<li>Version 1.1.4 fevrier, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 Septembre 2007. Possibilit&eacute; d&#039;afficher uniquement les nouvelles versions.  Ajout d&#039;un message apr&egrave;s la mise &agrave; jour des pr&eacute;f&eacute;rences</li>
<li>Version 1.1.6 Mai 2008. Affiche maintenant si les modules sont incompatibles avec la version courante CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li></ul>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
<p>Un client pour le d&eacute;pot de modules (ModuleRepository), ce module permet la pr&eacute;visualisation, et l&#039;installation de modules depuis des sites distants sans avoir besoin d&#039;utiliser le ftp, ou de d&eacute;zipper des archives. Les fichier XML de modules sont t&eacute;l&eacute;charg&eacute;s en utilisant SOAP, l&#039;int&eacute;grit&eacute; est v&eacute;rifi&eacute;e et automatiquement ajust&eacute;e.</p>
<h3>Comment l&#039;utiliser&nbsp;?</h3>
<p>pour utiliser ce module, vous devez d&eacute;finir la permission &#039;Modify Modules&#039;, vous avez aussi besoin de l&#039;URL complet &agrave; un d&eacute;p&ocirc;t de modules (Module Repository).  Vous pouvez sp&eacute;cifier cet URL dans le menu &#039;Administration du site&#039; --> &#039;Param&egrave;tres Globaux&#039;.</p><br/>
<p>Vous trouverez l&#039;interface de ce module sous le menu &#039;Extensions&#039;.  Quand vous s&eacute;lectionnez ce module, une requ&ecirc;te va automatiquement &ecirc;tre au d&eacute;p&ocirc;t de modules, pour trouver les modules XML disponibles. Cette liste sera compar&eacute;e &agrave; la liste des modules d&eacute;j&agrave; install&eacute;s, et une page de sommaire sera affich&eacute;e.  Puis, vous pourrez voir une information descriptive, l&#039;aide et l&#039;information &#039;&Agrave; propos&#039; des modules, sans les installer. Vous pourrez alors choisir de mettre &agrave; jour, ou installer des modules.</p>
<h3>Support</h3>
<p>Copyright &copy; 2006, Robert Campbell calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. Tous droits r&eacute;serv&eacute;s.</p>
<p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL" target="_blank">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>';
$lang['utma'] = '156861353.89360749.1215357409.1228149673.1229859907.64';
$lang['utmz'] = '156861353.1228149673.63.38.utmcsr=apa-sante.fr|utmccn=(referral)|utmcmd=referral|utmcct=/page/index.php';
$lang['utmb'] = '156861353.1.10.1229859907';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.6.6.tgz: cms/modules/ModuleManager/lang/ext/fr_FR.php <==
<?php
$lang['available_updates'] = 'Modules disponibles pour mise &agrave; jour';
$lang['all_modules_up_to_date'] = 'Il n&#039;y a pas de nouveaux modules disponibles dans le d&eacute;pot s&eacute;lectionn&eacute;';
$lang['error_module_object'] = 'Erreur : Ne peut pas obtenir une instance du module %s';
$lang['error_nomatchingmodules'] = 'Erreur : Ne pas trouver des modules dans le d&eacute;pot s&eacute;lectionn&eacute;';
$lang['error_nomodules'] = 'Erreur : Ne peut pas r&eacute;cup&eacute;rer la liste des modules install&eacute;s';
$lang['upgrade_available'] = 'Nouvelle version disponible (%s), vous avez la (%s)';
$lang['newversions'] = 'Modules install&eacute;s';
$lang['error_depends'] = 'Une ou plusieures d&eacute;pendances ne sont pas install&eacute;es. Vous devez installer d&#039;abord les d&eacute;pendances !';
$lang['msg_nodependencies'] = 'Ce fichier n&#039;a pas de liste des d&eacute;pendances';
$lang['dependstxt'] = 'D&eacute;pendances';
$lang['use_at_your_own_risk'] = 'Utilisation &agrave; vos risques et p&eacute;rils';
$lang['compatibility_disclaimer'] = 'Les modules affich&eacute;s ici sont fournis par les d&eacute;veloppeurs de CMS, et des tiers ind&eacute;pendants. Nous ne pouvons garantir que les modules offerts ici soit fonctionnels, test&eacute;s, ou compatibles avec votre syst&egrave;me. Vous &ecirc;tes encourag&eacute;s &agrave; lire les informations qui se trouvent dans l&#039;aide et sur les liens pour chaque module avant l&#039;installation.';
$lang['notice'] = 'Avertissement';
$lang['general_notice'] = 'Les version affich&eacute;es ici repr&eacute;sentent les derniers fichiers au format XML de votre d&eacute;pot s&eacute;lectionn&eacute; (CMSMS %s). Ils peuvent &ecirc;tre ou non la derniere version disponible.';
$lang['incompatible'] = 'Incompatible ';
$lang['prompt_settings'] = 'Configuration';
$lang['prompt_otheroptions'] = 'Autres options';
$lang['reset'] = 'R&eacute;initialisation';
$lang['error_permissions'] = '<strong><em>ATTENTION :</em></strong>Vous n&#039;avez pas les permissions suffisantes pour installer les modules. Vous pouvez avoir des prob&egrave;mes avec PHP Safe mode. Merci de v&eacute;rifier que le safe mode est OFF, et que les permissions des fichiers sont suffisantes.';
$lang['error_minimumrepository'] = 'La version du d&eacute;pot de modules n&#039;est pas compatible avec ce &quot;module manager&quot;';
$lang['prompt_reseturl'] = 'Remettre l&#039;URL par d&eacute;faut&nbsp;';
$lang['prompt_resetcache'] = 'Effacer les donn&eacute;es du cache local&nbsp;';
$lang['prompt_dl_chunksize'] = 'Taille de t&eacute;l&eacute;chargement (Kb)&nbsp;';
$lang['text_dl_chunksize'] = 'La taille maximale des donn&eacute;es &agrave; t&eacute;l&eacute;charger du serveur en une fois (lors de l&#039;installation d&#039;un module)';
$lang['error_nofilesize'] = 'Aucun param&egrave;tre de taill&eacute; sp&eacute;cifi&eacute;';
$lang['error_nofilename'] = 'Aucun param&egrave;tre de nom de fichier sp&eacute;cifi&eacute;';
$lang['error_checksum'] = 'Erreur Checksum. Ceci indique probablement qu&#039;il y a un fichier corrompu, soit lorsqu&#039;il a &eacute;t&eacute; t&eacute;l&eacute;charg&eacute; sur le d&eacute;p&ocirc;t s&eacute;lectionn&eacute;, soit lorsqu&#039;il a &eacute;t&eacute; transmis &agrave; votre machine.';
$lang['cantdownload'] = 'Impossible de t&eacute;l&eacute;charger';
$lang['download'] = 'T&eacute;l&eacute;charger et installer';
$lang['error_moduleinstallfailed'] = 'L&#039;installation du module a &eacute;chou&eacute;';
$lang['error_connectnomodules'] = 'Bien qu&#039;une connection au d&eacute;p&ocirc;t de module aie &eacute;t&eacute; &eacute;tablie avec succ&egrave;s, il appara&icirc;t que ce d&eacute;p&ocirc;t ne partage aucun module pour l&#039;instant.';
$lang['submit'] = 'Soumettre';
$lang['text_repository_url'] = 'L&#039;URL doit &ecirc;tre dans un format tel que http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'URL du d&eacute;p&ocirc;t de modules&nbsp;';
$lang['availmodules'] = 'Modules disponibles';
$lang['preferences'] = 'Pr&eacute;f&eacute;rences';
$lang['preferencessaved'] = 'Les pr&eacute;f&eacute;rences ont &eacute;t&eacute; mises &agrave; jour';
$lang['repositorycount'] = 'Modules trouv&eacute;s dans le d&eacute;p&ocirc;t';
$lang['instcount'] = 'Modules actuellement install&eacute;s';
$lang['availablemodules'] = 'Statut des modules disponibles dans le d&eacute;p&ocirc;t actuel';
$lang['helptxt'] = 'Aide';
$lang['abouttxt'] = '&Agrave; propos';
$lang['xmltext'] = 'Fichier XML';
$lang['nametext'] = 'Nom du module';
$lang['vertext'] = 'Version ';
$lang['sizetext'] = 'Taille (octets)';
$lang['statustext'] = 'Statut/Action';
$lang['uptodate'] = 'Install&eacute;';
$lang['install'] = 'installer';
$lang['newerversion'] = 'Nouvelle version install&eacute;e';
$lang['onlynewesttext'] = 'Afficher uniquement les nouvelles versions&nbsp;';
$lang['upgrade'] = 'Mise &agrave; jour';
$lang['error_nosoapconnect'] = 'Impossible de se connecter au serveur SOAP';
$lang['error_soaperror'] = 'Probl&egrave;me SOAP';
$lang['error_norepositoryurl'] = 'L&#039;URL du d&eacute;p&ocirc;t de module n&#039;a pas &eacute;t&eacute; sp&eacute;cifi&eacute;';
$lang['friendlyname'] = 'Gestionnaire de Modules';
$lang['postinstall'] = 'Module Manager a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
$lang['postuninstall'] = 'Le module Gestionnaire de modules (Module Manager) a &eacute;t&eacute; d&eacute;sinstall&eacute;. Les utilisateurs n&#039;auront plus la possibilit&eacute; d&#039;installer des modules depuis des d&eacute;p&ocirc;ts distants. Cependant, l&#039;installation locale est toujours possible.';
$lang['really_uninstall'] = '\u00CAtes-vous s\u00FBr de vouloir d\u00E9sinstaller ce module ? Vous allez perdre toutes ses fonctionalit\u00E9s.';
$lang['uninstalled'] = 'Module d&eacute;sinstall&eacute;.';
$lang['installed'] = 'La version %s du module est install&eacute;e.';
$lang['upgraded'] = 'Module mis &agrave; jour &agrave; la version %s.';
$lang['moddescription'] = 'Un client pour le d&eacute;pot de modules (ModuleRepository), ce module permet la pr&eacute;visualisation, et l&#039;installation de modules depuis des sites distants sans avoir besoin d&#039;utiliser le ftp, ou de d&eacute;zipper des archives. Les fichier XML de modules sont t&eacute;l&eacute;charg&eacute;s en utilisant SOAP, l&#039;int&eacute;grit&eacute; est v&eacute;rifi&eacute;e et automatiquement ajust&eacute;e.';
$lang['error'] = 'Erreur&nbsp;!';
$lang['admindescription'] = 'Un outils pour trouver et installer des modules depuis des sites distants.';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;, veuillez v&eacute;rifier les permissions.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 janvier 2006. Version initiale.</li>
<li>Version 1.1. juillet 2006. Distribu&eacute; avec 1.0- beta</li>
<li>Version 1.1.1 Ao&ucirc;t 2006.  Requiert la version 1.0.1 de nuSOAP</li>
<li>Version 1.1.2 septembre 2006.  Correction d&#039;une erreur qui emp&ecirc;chait les mises &agrave; jour</li>
<li>Version 1.1.3 Septembre, 2006.
  <ul>
  <li>Requiert au minimum CMS Version 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
<li>Version 1.1.4 fevrier, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 Septembre 2007. Possibilit&eacute; d&#039;afficher uniquement les nouvelles versions.  Ajout d&#039;un message apr&egrave;s la mise &agrave; jour des pr&eacute;f&eacute;rences</li>
<li>Version 1.1.6 Mai 2008. Affiche maintenant si les modules sont incompatibles avec la version courante CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li></ul>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
<li>Version 1.3 May, 2009.<br/>
Added dependency checking.
</li>
</ul>';
$lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
<p>Un client pour le d&eacute;pot de modules (ModuleRepository), ce module permet la pr&eacute;visualisation, et l&#039;installation de modules depuis des sites distants sans avoir besoin d&#039;utiliser le ftp, ou de d&eacute;zipper des archives. Les fichier XML de modules sont t&eacute;l&eacute;charg&eacute;s en utilisant SOAP, l&#039;int&eacute;grit&eacute; est v&eacute;rifi&eacute;e et automatiquement ajust&eacute;e.</p>
<h3>Comment l&#039;utiliser&nbsp;?</h3>
<p>pour utiliser ce module, vous devez d&eacute;finir la permission &#039;Modify Modules&#039;, vous avez aussi besoin de l&#039;URL complet &agrave; un d&eacute;p&ocirc;t de modules (Module Repository).  Vous pouvez sp&eacute;cifier cet URL dans le menu &quot;Extensions / Gestionnaire de Modules / Pr&eacute;f&eacute;rences&quot;.</p><br/>
<p>Vous trouverez l&#039;interface de ce module sous le menu &#039;Extensions&#039;.  Quand vous s&eacute;lectionnez ce module, une requ&ecirc;te va automatiquement &ecirc;tre au d&eacute;p&ocirc;t de modules, pour trouver les modules XML disponibles. Cette liste sera compar&eacute;e &agrave; la liste des modules d&eacute;j&agrave; install&eacute;s, et une page de sommaire sera affich&eacute;e.  Puis, vous pourrez voir une information descriptive, l&#039;aide et l&#039;information &#039;&Agrave; propos&#039; des modules, sans les installer. Vous pourrez alors choisir de mettre &agrave; jour, ou installer des modules.</p>
<h3>Support</h3>
<p>Copyright &copy; 2006,  <a href="mailto:calguy1000@hotmail.com">Robert Campbell calguy1000</a>. Tous droits r&eacute;serv&eacute;s.</p>
<p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL" target="_blank">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>';
$lang['utma'] = '156861353.253230781.1241719083.1241719083.1241719083.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1241719083.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
?>
